# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubemq/grpc/kubemq.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18kubemq/grpc/kubemq.proto\x12\x06kubemq\"a\n\nPingResult\x12\x0c\n\x04Host\x18\x01 \x01(\t\x12\x0f\n\x07Version\x18\x02 \x01(\t\x12\x17\n\x0fServerStartTime\x18\x03 \x01(\x03\x12\x1b\n\x13ServerUpTimeSeconds\x18\x04 \x01(\x03\"\x07\n\x05\x45mpty\"6\n\x06Result\x12\x0f\n\x07\x45ventID\x18\x01 \x01(\t\x12\x0c\n\x04Sent\x18\x02 \x01(\x08\x12\r\n\x05\x45rror\x18\x03 \x01(\t\"\xbe\x01\n\x05\x45vent\x12\x0f\n\x07\x45ventID\x18\x01 \x01(\t\x12\x10\n\x08\x43lientID\x18\x02 \x01(\t\x12\x0f\n\x07\x43hannel\x18\x03 \x01(\t\x12\x10\n\x08Metadata\x18\x04 \x01(\t\x12\x0c\n\x04\x42ody\x18\x05 \x01(\x0c\x12\r\n\x05Store\x18\x06 \x01(\x08\x12%\n\x04Tags\x18\x07 \x03(\x0b\x32\x17.kubemq.Event.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd0\x01\n\x0c\x45ventReceive\x12\x0f\n\x07\x45ventID\x18\x01 \x01(\t\x12\x0f\n\x07\x43hannel\x18\x02 \x01(\t\x12\x10\n\x08Metadata\x18\x03 \x01(\t\x12\x0c\n\x04\x42ody\x18\x04 \x01(\x0c\x12\x11\n\tTimestamp\x18\x05 \x01(\x03\x12\x10\n\x08Sequence\x18\x06 \x01(\x04\x12,\n\x04Tags\x18\x07 \x03(\x0b\x32\x1e.kubemq.EventReceive.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe3\x03\n\tSubscribe\x12:\n\x11SubscribeTypeData\x18\x01 \x01(\x0e\x32\x1f.kubemq.Subscribe.SubscribeType\x12\x10\n\x08\x43lientID\x18\x02 \x01(\t\x12\x0f\n\x07\x43hannel\x18\x03 \x01(\t\x12\r\n\x05Group\x18\x04 \x01(\t\x12>\n\x13\x45ventsStoreTypeData\x18\x05 \x01(\x0e\x32!.kubemq.Subscribe.EventsStoreType\x12\x1c\n\x14\x45ventsStoreTypeValue\x18\x06 \x01(\x03\"c\n\rSubscribeType\x12\x1a\n\x16SubscribeTypeUndefined\x10\x00\x12\n\n\x06\x45vents\x10\x01\x12\x0f\n\x0b\x45ventsStore\x10\x02\x12\x0c\n\x08\x43ommands\x10\x03\x12\x0b\n\x07Queries\x10\x04\"\xa4\x01\n\x0f\x45ventsStoreType\x12\x1c\n\x18\x45ventsStoreTypeUndefined\x10\x00\x12\x10\n\x0cStartNewOnly\x10\x01\x12\x12\n\x0eStartFromFirst\x10\x02\x12\x11\n\rStartFromLast\x10\x03\x12\x13\n\x0fStartAtSequence\x10\x04\x12\x0f\n\x0bStartAtTime\x10\x05\x12\x14\n\x10StartAtTimeDelta\x10\x06\"\x83\x03\n\x07Request\x12\x11\n\tRequestID\x18\x01 \x01(\t\x12\x34\n\x0fRequestTypeData\x18\x02 \x01(\x0e\x32\x1b.kubemq.Request.RequestType\x12\x10\n\x08\x43lientID\x18\x03 \x01(\t\x12\x0f\n\x07\x43hannel\x18\x04 \x01(\t\x12\x10\n\x08Metadata\x18\x05 \x01(\t\x12\x0c\n\x04\x42ody\x18\x06 \x01(\x0c\x12\x14\n\x0cReplyChannel\x18\x07 \x01(\t\x12\x0f\n\x07Timeout\x18\x08 \x01(\x05\x12\x10\n\x08\x43\x61\x63heKey\x18\t \x01(\t\x12\x10\n\x08\x43\x61\x63heTTL\x18\n \x01(\x05\x12\x0c\n\x04Span\x18\x0b \x01(\x0c\x12\'\n\x04Tags\x18\x0c \x03(\x0b\x32\x19.kubemq.Request.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"=\n\x0bRequestType\x12\x16\n\x12RequestTypeUnknown\x10\x00\x12\x0b\n\x07\x43ommand\x10\x01\x12\t\n\x05Query\x10\x02\"\x90\x02\n\x08Response\x12\x10\n\x08\x43lientID\x18\x01 \x01(\t\x12\x11\n\tRequestID\x18\x02 \x01(\t\x12\x14\n\x0cReplyChannel\x18\x03 \x01(\t\x12\x10\n\x08Metadata\x18\x04 \x01(\t\x12\x0c\n\x04\x42ody\x18\x05 \x01(\x0c\x12\x10\n\x08\x43\x61\x63heHit\x18\x06 \x01(\x08\x12\x11\n\tTimestamp\x18\x07 \x01(\x03\x12\x10\n\x08\x45xecuted\x18\x08 \x01(\x08\x12\r\n\x05\x45rror\x18\t \x01(\t\x12\x0c\n\x04Span\x18\n \x01(\x0c\x12(\n\x04Tags\x18\x0b \x03(\x0b\x32\x1a.kubemq.Response.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd7\x02\n\x0cQueueMessage\x12\x11\n\tMessageID\x18\x01 \x01(\t\x12\x10\n\x08\x43lientID\x18\x02 \x01(\t\x12\x0f\n\x07\x43hannel\x18\x03 \x01(\t\x12\x10\n\x08Metadata\x18\x04 \x01(\t\x12\x0c\n\x04\x42ody\x18\x05 \x01(\x0c\x12,\n\x04Tags\x18\x06 \x03(\x0b\x32\x1e.kubemq.QueueMessage.TagsEntry\x12\x32\n\nAttributes\x18\x07 \x01(\x0b\x32\x1e.kubemq.QueueMessageAttributes\x12*\n\x06Policy\x18\x08 \x01(\x0b\x32\x1a.kubemq.QueueMessagePolicy\x12\r\n\x05Topic\x18\t \x01(\t\x12\x11\n\tPartition\x18\n \x01(\x05\x12\x14\n\x0cPartitionKey\x18\x0b \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"T\n\x19QueueMessagesBatchRequest\x12\x0f\n\x07\x42\x61tchID\x18\x01 \x01(\t\x12&\n\x08Messages\x18\x02 \x03(\x0b\x32\x14.kubemq.QueueMessage\"r\n\x1aQueueMessagesBatchResponse\x12\x0f\n\x07\x42\x61tchID\x18\x01 \x01(\t\x12/\n\x07Results\x18\x02 \x03(\x0b\x32\x1e.kubemq.SendQueueMessageResult\x12\x12\n\nHaveErrors\x18\x03 \x01(\x08\"\xbc\x01\n\x16QueueMessageAttributes\x12\x11\n\tTimestamp\x18\x01 \x01(\x03\x12\x10\n\x08Sequence\x18\x02 \x01(\x04\x12\x11\n\tMD5OfBody\x18\x03 \x01(\t\x12\x14\n\x0cReceiveCount\x18\x04 \x01(\x05\x12\x10\n\x08ReRouted\x18\x05 \x01(\x08\x12\x19\n\x11ReRoutedFromQueue\x18\x06 \x01(\t\x12\x14\n\x0c\x45xpirationAt\x18\x07 \x01(\x03\x12\x11\n\tDelayedTo\x18\x08 \x01(\x03\"w\n\x12QueueMessagePolicy\x12\x19\n\x11\x45xpirationSeconds\x18\x01 \x01(\x05\x12\x14\n\x0c\x44\x65laySeconds\x18\x02 \x01(\x05\x12\x17\n\x0fMaxReceiveCount\x18\x03 \x01(\x05\x12\x17\n\x0fMaxReceiveQueue\x18\x04 \x01(\t\"\xd1\x01\n\x16SendQueueMessageResult\x12\x11\n\tMessageID\x18\x01 \x01(\t\x12\x0e\n\x06SentAt\x18\x02 \x01(\x03\x12\x14\n\x0c\x45xpirationAt\x18\x03 \x01(\x03\x12\x11\n\tDelayedTo\x18\x04 \x01(\x03\x12\x0f\n\x07IsError\x18\x05 \x01(\x08\x12\r\n\x05\x45rror\x18\x06 \x01(\t\x12\x12\n\nRefChannel\x18\x07 \x01(\t\x12\x10\n\x08RefTopic\x18\x08 \x01(\t\x12\x14\n\x0cRefPartition\x18\t \x01(\x05\x12\x0f\n\x07RefHash\x18\n \x01(\t\"\x99\x01\n\x1bReceiveQueueMessagesRequest\x12\x11\n\tRequestID\x18\x01 \x01(\t\x12\x10\n\x08\x43lientID\x18\x02 \x01(\t\x12\x0f\n\x07\x43hannel\x18\x03 \x01(\t\x12\x1b\n\x13MaxNumberOfMessages\x18\x04 \x01(\x05\x12\x17\n\x0fWaitTimeSeconds\x18\x05 \x01(\x05\x12\x0e\n\x06IsPeak\x18\x06 \x01(\x08\"\xbc\x01\n\x1cReceiveQueueMessagesResponse\x12\x11\n\tRequestID\x18\x01 \x01(\t\x12&\n\x08Messages\x18\x02 \x03(\x0b\x32\x14.kubemq.QueueMessage\x12\x18\n\x10MessagesReceived\x18\x03 \x01(\x05\x12\x17\n\x0fMessagesExpired\x18\x04 \x01(\x05\x12\x0e\n\x06IsPeak\x18\x05 \x01(\x08\x12\x0f\n\x07IsError\x18\x06 \x01(\x08\x12\r\n\x05\x45rror\x18\x07 \x01(\t\"k\n\x1a\x41\x63kAllQueueMessagesRequest\x12\x11\n\tRequestID\x18\x01 \x01(\t\x12\x10\n\x08\x43lientID\x18\x02 \x01(\t\x12\x0f\n\x07\x43hannel\x18\x03 \x01(\t\x12\x17\n\x0fWaitTimeSeconds\x18\x04 \x01(\x05\"j\n\x1b\x41\x63kAllQueueMessagesResponse\x12\x11\n\tRequestID\x18\x01 \x01(\t\x12\x18\n\x10\x41\x66\x66\x65\x63tedMessages\x18\x02 \x01(\x04\x12\x0f\n\x07IsError\x18\x03 \x01(\x08\x12\r\n\x05\x45rror\x18\x04 \x01(\t\"\x84\x02\n\x1aStreamQueueMessagesRequest\x12\x11\n\tRequestID\x18\x01 \x01(\t\x12\x10\n\x08\x43lientID\x18\x02 \x01(\t\x12\x38\n\x15StreamRequestTypeData\x18\x03 \x01(\x0e\x32\x19.kubemq.StreamRequestType\x12\x0f\n\x07\x43hannel\x18\x04 \x01(\t\x12\x19\n\x11VisibilitySeconds\x18\x05 \x01(\x05\x12\x17\n\x0fWaitTimeSeconds\x18\x06 \x01(\x05\x12\x13\n\x0bRefSequence\x18\x07 \x01(\x04\x12-\n\x0fModifiedMessage\x18\x08 \x01(\x0b\x32\x14.kubemq.QueueMessage\"\xb1\x01\n\x1bStreamQueueMessagesResponse\x12\x11\n\tRequestID\x18\x01 \x01(\t\x12\x38\n\x15StreamRequestTypeData\x18\x02 \x01(\x0e\x32\x19.kubemq.StreamRequestType\x12%\n\x07Message\x18\x03 \x01(\x0b\x32\x14.kubemq.QueueMessage\x12\x0f\n\x07IsError\x18\x04 \x01(\x08\x12\r\n\x05\x45rror\x18\x05 \x01(\t\"R\n\x15QueuesUpstreamRequest\x12\x11\n\tRequestID\x18\x01 \x01(\t\x12&\n\x08Messages\x18\x02 \x03(\x0b\x32\x14.kubemq.QueueMessage\"\x7f\n\x16QueuesUpstreamResponse\x12\x14\n\x0cRefRequestID\x18\x01 \x01(\t\x12/\n\x07Results\x18\x02 \x03(\x0b\x32\x1e.kubemq.SendQueueMessageResult\x12\x0f\n\x07IsError\x18\x03 \x01(\x08\x12\r\n\x05\x45rror\x18\x04 \x01(\t\"\x80\x03\n\x17QueuesDownstreamRequest\x12\x11\n\tRequestID\x18\x01 \x01(\t\x12\x10\n\x08\x43lientID\x18\x02 \x01(\t\x12<\n\x0fRequestTypeData\x18\x03 \x01(\x0e\x32#.kubemq.QueuesDownstreamRequestType\x12\x0f\n\x07\x43hannel\x18\x04 \x01(\t\x12\x10\n\x08MaxItems\x18\x05 \x01(\x05\x12\x13\n\x0bWaitTimeout\x18\x06 \x01(\x05\x12\x0f\n\x07\x41utoAck\x18\x07 \x01(\x08\x12\x16\n\x0eReQueueChannel\x18\x08 \x01(\t\x12\x15\n\rSequenceRange\x18\t \x03(\x03\x12\x18\n\x10RefTransactionId\x18\n \x01(\t\x12?\n\x08Metadata\x18\x0c \x03(\x0b\x32-.kubemq.QueuesDownstreamRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf4\x02\n\x18QueuesDownstreamResponse\x12\x15\n\rTransactionId\x18\x01 \x01(\t\x12\x14\n\x0cRefRequestId\x18\x02 \x01(\t\x12<\n\x0fRequestTypeData\x18\x03 \x01(\x0e\x32#.kubemq.QueuesDownstreamRequestType\x12&\n\x08Messages\x18\x04 \x03(\x0b\x32\x14.kubemq.QueueMessage\x12\x15\n\rActiveOffsets\x18\x05 \x03(\x03\x12\x0f\n\x07IsError\x18\x06 \x01(\x08\x12\r\n\x05\x45rror\x18\x07 \x01(\t\x12\x1b\n\x13TransactionComplete\x18\x08 \x01(\x08\x12@\n\x08Metadata\x18\t \x03(\x0b\x32..kubemq.QueuesDownstreamResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xae\x01\n\tQueueInfo\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x10\n\x08Messages\x18\x02 \x01(\x03\x12\r\n\x05\x42ytes\x18\x03 \x01(\x03\x12\x15\n\rFirstSequence\x18\x04 \x01(\x03\x12\x14\n\x0cLastSequence\x18\x05 \x01(\x03\x12\x0c\n\x04Sent\x18\x06 \x01(\x03\x12\x11\n\tDelivered\x18\x07 \x01(\x03\x12\x0f\n\x07Waiting\x18\x08 \x01(\x03\x12\x13\n\x0bSubscribers\x18\t \x01(\x03\"u\n\nQueuesInfo\x12\x12\n\nTotalQueue\x18\x01 \x01(\x05\x12\x0c\n\x04Sent\x18\x02 \x01(\x03\x12\x11\n\tDelivered\x18\x03 \x01(\x03\x12\x0f\n\x07Waiting\x18\x04 \x01(\x03\x12!\n\x06Queues\x18\x05 \x03(\x0b\x32\x11.kubemq.QueueInfo\"9\n\x11QueuesInfoRequest\x12\x11\n\tRequestID\x18\x01 \x01(\t\x12\x11\n\tQueueName\x18\x02 \x01(\t\"L\n\x12QueuesInfoResponse\x12\x14\n\x0cRefRequestID\x18\x01 \x01(\t\x12 \n\x04Info\x18\x02 \x01(\x0b\x32\x12.kubemq.QueuesInfo*\xaa\x01\n\x11StreamRequestType\x12\x1c\n\x18StreamRequestTypeUnknown\x10\x00\x12\x12\n\x0eReceiveMessage\x10\x01\x12\x0e\n\nAckMessage\x10\x02\x12\x11\n\rRejectMessage\x10\x03\x12\x14\n\x10ModifyVisibility\x10\x04\x12\x11\n\rResendMessage\x10\x05\x12\x17\n\x13SendModifiedMessage\x10\x06*\xea\x01\n\x1bQueuesDownstreamRequestType\x12\x1a\n\x16PollRequestTypeUnknown\x10\x00\x12\x07\n\x03Get\x10\x01\x12\n\n\x06\x41\x63kAll\x10\x02\x12\x0c\n\x08\x41\x63kRange\x10\x03\x12\x0b\n\x07NAckAll\x10\x04\x12\r\n\tNAckRange\x10\x05\x12\x0e\n\nReQueueAll\x10\x06\x12\x10\n\x0cReQueueRange\x10\x07\x12\x11\n\rActiveOffsets\x10\x08\x12\x15\n\x11TransactionStatus\x10\t\x12\x11\n\rCloseByClient\x10\n\x12\x11\n\rCloseByServer\x10\x0b\x32\xda\x08\n\x06kubemq\x12,\n\tSendEvent\x12\r.kubemq.Event\x1a\x0e.kubemq.Result\"\x00\x12\x37\n\x10SendEventsStream\x12\r.kubemq.Event\x1a\x0e.kubemq.Result\"\x00(\x01\x30\x01\x12@\n\x11SubscribeToEvents\x12\x11.kubemq.Subscribe\x1a\x14.kubemq.EventReceive\"\x00\x30\x01\x12=\n\x13SubscribeToRequests\x12\x11.kubemq.Subscribe\x1a\x0f.kubemq.Request\"\x00\x30\x01\x12\x32\n\x0bSendRequest\x12\x0f.kubemq.Request\x1a\x10.kubemq.Response\"\x00\x12\x31\n\x0cSendResponse\x12\x10.kubemq.Response\x1a\r.kubemq.Empty\"\x00\x12J\n\x10SendQueueMessage\x12\x14.kubemq.QueueMessage\x1a\x1e.kubemq.SendQueueMessageResult\"\x00\x12\x61\n\x16SendQueueMessagesBatch\x12!.kubemq.QueueMessagesBatchRequest\x1a\".kubemq.QueueMessagesBatchResponse\"\x00\x12\x63\n\x14ReceiveQueueMessages\x12#.kubemq.ReceiveQueueMessagesRequest\x1a$.kubemq.ReceiveQueueMessagesResponse\"\x00\x12\x63\n\x12StreamQueueMessage\x12\".kubemq.StreamQueueMessagesRequest\x1a#.kubemq.StreamQueueMessagesResponse\"\x00(\x01\x30\x01\x12`\n\x13\x41\x63kAllQueueMessages\x12\".kubemq.AckAllQueueMessagesRequest\x1a#.kubemq.AckAllQueueMessagesResponse\"\x00\x12+\n\x04Ping\x12\r.kubemq.Empty\x1a\x12.kubemq.PingResult\"\x00\x12[\n\x10QueuesDownstream\x12\x1f.kubemq.QueuesDownstreamRequest\x1a .kubemq.QueuesDownstreamResponse\"\x00(\x01\x30\x01\x12U\n\x0eQueuesUpstream\x12\x1d.kubemq.QueuesUpstreamRequest\x1a\x1e.kubemq.QueuesUpstreamResponse\"\x00(\x01\x30\x01\x12\x45\n\nQueuesInfo\x12\x19.kubemq.QueuesInfoRequest\x1a\x1a.kubemq.QueuesInfoResponse\"\x00\x42\x10\xaa\x02\rKubeMQ.Clientb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubemq.grpc.kubemq_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\rKubeMQ.Client'
  _globals['_EVENT_TAGSENTRY']._options = None
  _globals['_EVENT_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_EVENTRECEIVE_TAGSENTRY']._options = None
  _globals['_EVENTRECEIVE_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_REQUEST_TAGSENTRY']._options = None
  _globals['_REQUEST_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_RESPONSE_TAGSENTRY']._options = None
  _globals['_RESPONSE_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_QUEUEMESSAGE_TAGSENTRY']._options = None
  _globals['_QUEUEMESSAGE_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_QUEUESDOWNSTREAMREQUEST_METADATAENTRY']._options = None
  _globals['_QUEUESDOWNSTREAMREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_QUEUESDOWNSTREAMRESPONSE_METADATAENTRY']._options = None
  _globals['_QUEUESDOWNSTREAMRESPONSE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_STREAMREQUESTTYPE']._serialized_start=5243
  _globals['_STREAMREQUESTTYPE']._serialized_end=5413
  _globals['_QUEUESDOWNSTREAMREQUESTTYPE']._serialized_start=5416
  _globals['_QUEUESDOWNSTREAMREQUESTTYPE']._serialized_end=5650
  _globals['_PINGRESULT']._serialized_start=36
  _globals['_PINGRESULT']._serialized_end=133
  _globals['_EMPTY']._serialized_start=135
  _globals['_EMPTY']._serialized_end=142
  _globals['_RESULT']._serialized_start=144
  _globals['_RESULT']._serialized_end=198
  _globals['_EVENT']._serialized_start=201
  _globals['_EVENT']._serialized_end=391
  _globals['_EVENT_TAGSENTRY']._serialized_start=348
  _globals['_EVENT_TAGSENTRY']._serialized_end=391
  _globals['_EVENTRECEIVE']._serialized_start=394
  _globals['_EVENTRECEIVE']._serialized_end=602
  _globals['_EVENTRECEIVE_TAGSENTRY']._serialized_start=348
  _globals['_EVENTRECEIVE_TAGSENTRY']._serialized_end=391
  _globals['_SUBSCRIBE']._serialized_start=605
  _globals['_SUBSCRIBE']._serialized_end=1088
  _globals['_SUBSCRIBE_SUBSCRIBETYPE']._serialized_start=822
  _globals['_SUBSCRIBE_SUBSCRIBETYPE']._serialized_end=921
  _globals['_SUBSCRIBE_EVENTSSTORETYPE']._serialized_start=924
  _globals['_SUBSCRIBE_EVENTSSTORETYPE']._serialized_end=1088
  _globals['_REQUEST']._serialized_start=1091
  _globals['_REQUEST']._serialized_end=1478
  _globals['_REQUEST_TAGSENTRY']._serialized_start=348
  _globals['_REQUEST_TAGSENTRY']._serialized_end=391
  _globals['_REQUEST_REQUESTTYPE']._serialized_start=1417
  _globals['_REQUEST_REQUESTTYPE']._serialized_end=1478
  _globals['_RESPONSE']._serialized_start=1481
  _globals['_RESPONSE']._serialized_end=1753
  _globals['_RESPONSE_TAGSENTRY']._serialized_start=348
  _globals['_RESPONSE_TAGSENTRY']._serialized_end=391
  _globals['_QUEUEMESSAGE']._serialized_start=1756
  _globals['_QUEUEMESSAGE']._serialized_end=2099
  _globals['_QUEUEMESSAGE_TAGSENTRY']._serialized_start=348
  _globals['_QUEUEMESSAGE_TAGSENTRY']._serialized_end=391
  _globals['_QUEUEMESSAGESBATCHREQUEST']._serialized_start=2101
  _globals['_QUEUEMESSAGESBATCHREQUEST']._serialized_end=2185
  _globals['_QUEUEMESSAGESBATCHRESPONSE']._serialized_start=2187
  _globals['_QUEUEMESSAGESBATCHRESPONSE']._serialized_end=2301
  _globals['_QUEUEMESSAGEATTRIBUTES']._serialized_start=2304
  _globals['_QUEUEMESSAGEATTRIBUTES']._serialized_end=2492
  _globals['_QUEUEMESSAGEPOLICY']._serialized_start=2494
  _globals['_QUEUEMESSAGEPOLICY']._serialized_end=2613
  _globals['_SENDQUEUEMESSAGERESULT']._serialized_start=2616
  _globals['_SENDQUEUEMESSAGERESULT']._serialized_end=2825
  _globals['_RECEIVEQUEUEMESSAGESREQUEST']._serialized_start=2828
  _globals['_RECEIVEQUEUEMESSAGESREQUEST']._serialized_end=2981
  _globals['_RECEIVEQUEUEMESSAGESRESPONSE']._serialized_start=2984
  _globals['_RECEIVEQUEUEMESSAGESRESPONSE']._serialized_end=3172
  _globals['_ACKALLQUEUEMESSAGESREQUEST']._serialized_start=3174
  _globals['_ACKALLQUEUEMESSAGESREQUEST']._serialized_end=3281
  _globals['_ACKALLQUEUEMESSAGESRESPONSE']._serialized_start=3283
  _globals['_ACKALLQUEUEMESSAGESRESPONSE']._serialized_end=3389
  _globals['_STREAMQUEUEMESSAGESREQUEST']._serialized_start=3392
  _globals['_STREAMQUEUEMESSAGESREQUEST']._serialized_end=3652
  _globals['_STREAMQUEUEMESSAGESRESPONSE']._serialized_start=3655
  _globals['_STREAMQUEUEMESSAGESRESPONSE']._serialized_end=3832
  _globals['_QUEUESUPSTREAMREQUEST']._serialized_start=3834
  _globals['_QUEUESUPSTREAMREQUEST']._serialized_end=3916
  _globals['_QUEUESUPSTREAMRESPONSE']._serialized_start=3918
  _globals['_QUEUESUPSTREAMRESPONSE']._serialized_end=4045
  _globals['_QUEUESDOWNSTREAMREQUEST']._serialized_start=4048
  _globals['_QUEUESDOWNSTREAMREQUEST']._serialized_end=4432
  _globals['_QUEUESDOWNSTREAMREQUEST_METADATAENTRY']._serialized_start=4385
  _globals['_QUEUESDOWNSTREAMREQUEST_METADATAENTRY']._serialized_end=4432
  _globals['_QUEUESDOWNSTREAMRESPONSE']._serialized_start=4435
  _globals['_QUEUESDOWNSTREAMRESPONSE']._serialized_end=4807
  _globals['_QUEUESDOWNSTREAMRESPONSE_METADATAENTRY']._serialized_start=4385
  _globals['_QUEUESDOWNSTREAMRESPONSE_METADATAENTRY']._serialized_end=4432
  _globals['_QUEUEINFO']._serialized_start=4810
  _globals['_QUEUEINFO']._serialized_end=4984
  _globals['_QUEUESINFO']._serialized_start=4986
  _globals['_QUEUESINFO']._serialized_end=5103
  _globals['_QUEUESINFOREQUEST']._serialized_start=5105
  _globals['_QUEUESINFOREQUEST']._serialized_end=5162
  _globals['_QUEUESINFORESPONSE']._serialized_start=5164
  _globals['_QUEUESINFORESPONSE']._serialized_end=5240
  _globals['_KUBEMQ']._serialized_start=5653
  _globals['_KUBEMQ']._serialized_end=6767
# @@protoc_insertion_point(module_scope)



class KeepAliveConfig:
    """
    Represents the configuration for keep alive functionality.

    Args:
        enabled (bool, optional): Specifies if keep alive is enabled. Default is False.
        ping_interval_in_seconds (int, optional): The interval at which ping requests are sent in seconds.
                                                  Default is 0.
        ping_timeout_in_seconds (int, optional): The timeout for ping requests in seconds. Default is 0.

    Attributes:
        enabled (bool): Specifies if keep alive is enabled.
        ping_interval_in_seconds (int): The interval at which ping requests are sent in seconds.
        ping_timeout_in_seconds (int): The timeout for ping requests in seconds.

    Methods:
        validate(): Validates the keep alive configuration.

    Raises:
        ValueError: If enabled is True but ping_interval_in_seconds or ping_timeout_in_seconds is less than or equal to 0.
    """
    def __init__(self, enabled: bool = False,
                 ping_interval_in_seconds: int = 0,
                 ping_timeout_in_seconds: int = 0) -> None:
        self._enabled: bool = enabled
        self._ping_interval_in_seconds: int = ping_interval_in_seconds
        self._ping_timeout_in_seconds: int = ping_timeout_in_seconds

    @property
    def enabled(self) -> bool:
        return self._enabled

    @enabled.setter
    def enabled(self, value: bool) -> None:
        self._enabled = value

    @property
    def ping_interval_in_seconds(self) -> int:
        return self._ping_interval_in_seconds

    @ping_interval_in_seconds.setter
    def ping_interval_in_seconds(self, value: int) -> None:
        self._ping_interval_in_seconds = value

    @property
    def ping_timeout_in_seconds(self) -> int:
        return self._ping_timeout_in_seconds

    @ping_timeout_in_seconds.setter
    def ping_timeout_in_seconds(self, value: int) -> None:
        self._ping_timeout_in_seconds = value

    def validate(self) -> None:
        if not self._enabled:
            return
        if self._ping_interval_in_seconds <= 0:
            raise ValueError("Keep alive ping interval must be greater than 0")
        if self._ping_timeout_in_seconds <= 0:
            raise ValueError("Keep alive ping timeout must be greater than 0")



from pydantic import BaseModel, Field, field_validator
from typing import Optional
import uuid
from kubemq.grpc import QueuesDownstreamRequest, QueuesDownstreamRequestType


class QueuesPollRequest(BaseModel):
    """
    Class representing a request to poll messages from a queue.

    Attributes:
        channel (str): The channel to subscribe to.
        poll_max_messages (int): The maximum number of messages to poll in a single request.
        poll_wait_timeout_in_seconds (int): The maximum time to wait for messages in seconds.
        auto_ack_messages (bool): Whether to automatically acknowledge received messages.
    """

    channel: Optional[str] = Field(
        default=None, description="The channel to subscribe to"
    )
    poll_max_messages: int = Field(
        default=1,
        ge=1,
        description="The maximum number of messages to poll in a single request",
    )
    poll_wait_timeout_in_seconds: int = Field(
        default=60, ge=1, description="The maximum time to wait for messages in seconds"
    )
    auto_ack_messages: bool = Field(
        default=False,
        description="Whether to automatically acknowledge received messages",
    )

    @field_validator("channel")
    def channel_must_not_be_empty(cls, v: Optional[str]) -> str:
        if not v:
            raise ValueError("queue subscription must have a channel.")
        return v

    def encode(self, client_id: str = "") -> QueuesDownstreamRequest:
        request = QueuesDownstreamRequest()
        request.RequestID = str(uuid.uuid4())
        request.ClientID = client_id
        request.Channel = self.channel
        request.MaxItems = self.poll_max_messages
        request.WaitTimeout = self.poll_wait_timeout_in_seconds * 1000
        request.AutoAck = self.auto_ack_messages
        request.RequestTypeData = QueuesDownstreamRequestType.Get
        return request

    def __repr__(self):
        return (
            f"QueuesSubscription: channel={self.channel}, poll_max_messages={self.poll_max_messages}, "
            f"poll_wait_timeout_in_seconds={self.poll_wait_timeout_in_seconds}, auto_ack_messages={self.auto_ack_messages}"
        )

    class Config:
        arbitrary_types_allowed = True



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StreamRequestType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    StreamRequestTypeUnknown: _ClassVar[StreamRequestType]
    ReceiveMessage: _ClassVar[StreamRequestType]
    AckMessage: _ClassVar[StreamRequestType]
    RejectMessage: _ClassVar[StreamRequestType]
    ModifyVisibility: _ClassVar[StreamRequestType]
    ResendMessage: _ClassVar[StreamRequestType]
    SendModifiedMessage: _ClassVar[StreamRequestType]

class QueuesDownstreamRequestType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PollRequestTypeUnknown: _ClassVar[QueuesDownstreamRequestType]
    Get: _ClassVar[QueuesDownstreamRequestType]
    AckAll: _ClassVar[QueuesDownstreamRequestType]
    AckRange: _ClassVar[QueuesDownstreamRequestType]
    NAckAll: _ClassVar[QueuesDownstreamRequestType]
    NAckRange: _ClassVar[QueuesDownstreamRequestType]
    ReQueueAll: _ClassVar[QueuesDownstreamRequestType]
    ReQueueRange: _ClassVar[QueuesDownstreamRequestType]
    ActiveOffsets: _ClassVar[QueuesDownstreamRequestType]
    TransactionStatus: _ClassVar[QueuesDownstreamRequestType]
    CloseByClient: _ClassVar[QueuesDownstreamRequestType]
    CloseByServer: _ClassVar[QueuesDownstreamRequestType]
StreamRequestTypeUnknown: StreamRequestType
ReceiveMessage: StreamRequestType
AckMessage: StreamRequestType
RejectMessage: StreamRequestType
ModifyVisibility: StreamRequestType
ResendMessage: StreamRequestType
SendModifiedMessage: StreamRequestType
PollRequestTypeUnknown: QueuesDownstreamRequestType
Get: QueuesDownstreamRequestType
AckAll: QueuesDownstreamRequestType
AckRange: QueuesDownstreamRequestType
NAckAll: QueuesDownstreamRequestType
NAckRange: QueuesDownstreamRequestType
ReQueueAll: QueuesDownstreamRequestType
ReQueueRange: QueuesDownstreamRequestType
ActiveOffsets: QueuesDownstreamRequestType
TransactionStatus: QueuesDownstreamRequestType
CloseByClient: QueuesDownstreamRequestType
CloseByServer: QueuesDownstreamRequestType

class PingResult(_message.Message):
    __slots__ = ("Host", "Version", "ServerStartTime", "ServerUpTimeSeconds")
    HOST_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    SERVERSTARTTIME_FIELD_NUMBER: _ClassVar[int]
    SERVERUPTIMESECONDS_FIELD_NUMBER: _ClassVar[int]
    Host: str
    Version: str
    ServerStartTime: int
    ServerUpTimeSeconds: int
    def __init__(self, Host: _Optional[str] = ..., Version: _Optional[str] = ..., ServerStartTime: _Optional[int] = ..., ServerUpTimeSeconds: _Optional[int] = ...) -> None: ...

class Empty(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class Result(_message.Message):
    __slots__ = ("EventID", "Sent", "Error")
    EVENTID_FIELD_NUMBER: _ClassVar[int]
    SENT_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    EventID: str
    Sent: bool
    Error: str
    def __init__(self, EventID: _Optional[str] = ..., Sent: bool = ..., Error: _Optional[str] = ...) -> None: ...

class Event(_message.Message):
    __slots__ = ("EventID", "ClientID", "Channel", "Metadata", "Body", "Store", "Tags")
    class TagsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    EVENTID_FIELD_NUMBER: _ClassVar[int]
    CLIENTID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    STORE_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    EventID: str
    ClientID: str
    Channel: str
    Metadata: str
    Body: bytes
    Store: bool
    Tags: _containers.ScalarMap[str, str]
    def __init__(self, EventID: _Optional[str] = ..., ClientID: _Optional[str] = ..., Channel: _Optional[str] = ..., Metadata: _Optional[str] = ..., Body: _Optional[bytes] = ..., Store: bool = ..., Tags: _Optional[_Mapping[str, str]] = ...) -> None: ...

class EventReceive(_message.Message):
    __slots__ = ("EventID", "Channel", "Metadata", "Body", "Timestamp", "Sequence", "Tags")
    class TagsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    EVENTID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    EventID: str
    Channel: str
    Metadata: str
    Body: bytes
    Timestamp: int
    Sequence: int
    Tags: _containers.ScalarMap[str, str]
    def __init__(self, EventID: _Optional[str] = ..., Channel: _Optional[str] = ..., Metadata: _Optional[str] = ..., Body: _Optional[bytes] = ..., Timestamp: _Optional[int] = ..., Sequence: _Optional[int] = ..., Tags: _Optional[_Mapping[str, str]] = ...) -> None: ...

class Subscribe(_message.Message):
    __slots__ = ("SubscribeTypeData", "ClientID", "Channel", "Group", "EventsStoreTypeData", "EventsStoreTypeValue")
    class SubscribeType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        SubscribeTypeUndefined: _ClassVar[Subscribe.SubscribeType]
        Events: _ClassVar[Subscribe.SubscribeType]
        EventsStore: _ClassVar[Subscribe.SubscribeType]
        Commands: _ClassVar[Subscribe.SubscribeType]
        Queries: _ClassVar[Subscribe.SubscribeType]
    SubscribeTypeUndefined: Subscribe.SubscribeType
    Events: Subscribe.SubscribeType
    EventsStore: Subscribe.SubscribeType
    Commands: Subscribe.SubscribeType
    Queries: Subscribe.SubscribeType
    class EventsStoreType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        EventsStoreTypeUndefined: _ClassVar[Subscribe.EventsStoreType]
        StartNewOnly: _ClassVar[Subscribe.EventsStoreType]
        StartFromFirst: _ClassVar[Subscribe.EventsStoreType]
        StartFromLast: _ClassVar[Subscribe.EventsStoreType]
        StartAtSequence: _ClassVar[Subscribe.EventsStoreType]
        StartAtTime: _ClassVar[Subscribe.EventsStoreType]
        StartAtTimeDelta: _ClassVar[Subscribe.EventsStoreType]
    EventsStoreTypeUndefined: Subscribe.EventsStoreType
    StartNewOnly: Subscribe.EventsStoreType
    StartFromFirst: Subscribe.EventsStoreType
    StartFromLast: Subscribe.EventsStoreType
    StartAtSequence: Subscribe.EventsStoreType
    StartAtTime: Subscribe.EventsStoreType
    StartAtTimeDelta: Subscribe.EventsStoreType
    SUBSCRIBETYPEDATA_FIELD_NUMBER: _ClassVar[int]
    CLIENTID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    EVENTSSTORETYPEDATA_FIELD_NUMBER: _ClassVar[int]
    EVENTSSTORETYPEVALUE_FIELD_NUMBER: _ClassVar[int]
    SubscribeTypeData: Subscribe.SubscribeType
    ClientID: str
    Channel: str
    Group: str
    EventsStoreTypeData: Subscribe.EventsStoreType
    EventsStoreTypeValue: int
    def __init__(self, SubscribeTypeData: _Optional[_Union[Subscribe.SubscribeType, str]] = ..., ClientID: _Optional[str] = ..., Channel: _Optional[str] = ..., Group: _Optional[str] = ..., EventsStoreTypeData: _Optional[_Union[Subscribe.EventsStoreType, str]] = ..., EventsStoreTypeValue: _Optional[int] = ...) -> None: ...

class Request(_message.Message):
    __slots__ = ("RequestID", "RequestTypeData", "ClientID", "Channel", "Metadata", "Body", "ReplyChannel", "Timeout", "CacheKey", "CacheTTL", "Span", "Tags")
    class RequestType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        RequestTypeUnknown: _ClassVar[Request.RequestType]
        Command: _ClassVar[Request.RequestType]
        Query: _ClassVar[Request.RequestType]
    RequestTypeUnknown: Request.RequestType
    Command: Request.RequestType
    Query: Request.RequestType
    class TagsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    REQUESTID_FIELD_NUMBER: _ClassVar[int]
    REQUESTTYPEDATA_FIELD_NUMBER: _ClassVar[int]
    CLIENTID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    REPLYCHANNEL_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    CACHEKEY_FIELD_NUMBER: _ClassVar[int]
    CACHETTL_FIELD_NUMBER: _ClassVar[int]
    SPAN_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    RequestID: str
    RequestTypeData: Request.RequestType
    ClientID: str
    Channel: str
    Metadata: str
    Body: bytes
    ReplyChannel: str
    Timeout: int
    CacheKey: str
    CacheTTL: int
    Span: bytes
    Tags: _containers.ScalarMap[str, str]
    def __init__(self, RequestID: _Optional[str] = ..., RequestTypeData: _Optional[_Union[Request.RequestType, str]] = ..., ClientID: _Optional[str] = ..., Channel: _Optional[str] = ..., Metadata: _Optional[str] = ..., Body: _Optional[bytes] = ..., ReplyChannel: _Optional[str] = ..., Timeout: _Optional[int] = ..., CacheKey: _Optional[str] = ..., CacheTTL: _Optional[int] = ..., Span: _Optional[bytes] = ..., Tags: _Optional[_Mapping[str, str]] = ...) -> None: ...

class Response(_message.Message):
    __slots__ = ("ClientID", "RequestID", "ReplyChannel", "Metadata", "Body", "CacheHit", "Timestamp", "Executed", "Error", "Span", "Tags")
    class TagsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CLIENTID_FIELD_NUMBER: _ClassVar[int]
    REQUESTID_FIELD_NUMBER: _ClassVar[int]
    REPLYCHANNEL_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    CACHEHIT_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    EXECUTED_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    SPAN_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    ClientID: str
    RequestID: str
    ReplyChannel: str
    Metadata: str
    Body: bytes
    CacheHit: bool
    Timestamp: int
    Executed: bool
    Error: str
    Span: bytes
    Tags: _containers.ScalarMap[str, str]
    def __init__(self, ClientID: _Optional[str] = ..., RequestID: _Optional[str] = ..., ReplyChannel: _Optional[str] = ..., Metadata: _Optional[str] = ..., Body: _Optional[bytes] = ..., CacheHit: bool = ..., Timestamp: _Optional[int] = ..., Executed: bool = ..., Error: _Optional[str] = ..., Span: _Optional[bytes] = ..., Tags: _Optional[_Mapping[str, str]] = ...) -> None: ...

class QueueMessage(_message.Message):
    __slots__ = ("MessageID", "ClientID", "Channel", "Metadata", "Body", "Tags", "Attributes", "Policy", "Topic", "Partition", "PartitionKey")
    class TagsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    MESSAGEID_FIELD_NUMBER: _ClassVar[int]
    CLIENTID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    TOPIC_FIELD_NUMBER: _ClassVar[int]
    PARTITION_FIELD_NUMBER: _ClassVar[int]
    PARTITIONKEY_FIELD_NUMBER: _ClassVar[int]
    MessageID: str
    ClientID: str
    Channel: str
    Metadata: str
    Body: bytes
    Tags: _containers.ScalarMap[str, str]
    Attributes: QueueMessageAttributes
    Policy: QueueMessagePolicy
    Topic: str
    Partition: int
    PartitionKey: str
    def __init__(self, MessageID: _Optional[str] = ..., ClientID: _Optional[str] = ..., Channel: _Optional[str] = ..., Metadata: _Optional[str] = ..., Body: _Optional[bytes] = ..., Tags: _Optional[_Mapping[str, str]] = ..., Attributes: _Optional[_Union[QueueMessageAttributes, _Mapping]] = ..., Policy: _Optional[_Union[QueueMessagePolicy, _Mapping]] = ..., Topic: _Optional[str] = ..., Partition: _Optional[int] = ..., PartitionKey: _Optional[str] = ...) -> None: ...

class QueueMessagesBatchRequest(_message.Message):
    __slots__ = ("BatchID", "Messages")
    BATCHID_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    BatchID: str
    Messages: _containers.RepeatedCompositeFieldContainer[QueueMessage]
    def __init__(self, BatchID: _Optional[str] = ..., Messages: _Optional[_Iterable[_Union[QueueMessage, _Mapping]]] = ...) -> None: ...

class QueueMessagesBatchResponse(_message.Message):
    __slots__ = ("BatchID", "Results", "HaveErrors")
    BATCHID_FIELD_NUMBER: _ClassVar[int]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    HAVEERRORS_FIELD_NUMBER: _ClassVar[int]
    BatchID: str
    Results: _containers.RepeatedCompositeFieldContainer[SendQueueMessageResult]
    HaveErrors: bool
    def __init__(self, BatchID: _Optional[str] = ..., Results: _Optional[_Iterable[_Union[SendQueueMessageResult, _Mapping]]] = ..., HaveErrors: bool = ...) -> None: ...

class QueueMessageAttributes(_message.Message):
    __slots__ = ("Timestamp", "Sequence", "MD5OfBody", "ReceiveCount", "ReRouted", "ReRoutedFromQueue", "ExpirationAt", "DelayedTo")
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    MD5OFBODY_FIELD_NUMBER: _ClassVar[int]
    RECEIVECOUNT_FIELD_NUMBER: _ClassVar[int]
    REROUTED_FIELD_NUMBER: _ClassVar[int]
    REROUTEDFROMQUEUE_FIELD_NUMBER: _ClassVar[int]
    EXPIRATIONAT_FIELD_NUMBER: _ClassVar[int]
    DELAYEDTO_FIELD_NUMBER: _ClassVar[int]
    Timestamp: int
    Sequence: int
    MD5OfBody: str
    ReceiveCount: int
    ReRouted: bool
    ReRoutedFromQueue: str
    ExpirationAt: int
    DelayedTo: int
    def __init__(self, Timestamp: _Optional[int] = ..., Sequence: _Optional[int] = ..., MD5OfBody: _Optional[str] = ..., ReceiveCount: _Optional[int] = ..., ReRouted: bool = ..., ReRoutedFromQueue: _Optional[str] = ..., ExpirationAt: _Optional[int] = ..., DelayedTo: _Optional[int] = ...) -> None: ...

class QueueMessagePolicy(_message.Message):
    __slots__ = ("ExpirationSeconds", "DelaySeconds", "MaxReceiveCount", "MaxReceiveQueue")
    EXPIRATIONSECONDS_FIELD_NUMBER: _ClassVar[int]
    DELAYSECONDS_FIELD_NUMBER: _ClassVar[int]
    MAXRECEIVECOUNT_FIELD_NUMBER: _ClassVar[int]
    MAXRECEIVEQUEUE_FIELD_NUMBER: _ClassVar[int]
    ExpirationSeconds: int
    DelaySeconds: int
    MaxReceiveCount: int
    MaxReceiveQueue: str
    def __init__(self, ExpirationSeconds: _Optional[int] = ..., DelaySeconds: _Optional[int] = ..., MaxReceiveCount: _Optional[int] = ..., MaxReceiveQueue: _Optional[str] = ...) -> None: ...

class SendQueueMessageResult(_message.Message):
    __slots__ = ("MessageID", "SentAt", "ExpirationAt", "DelayedTo", "IsError", "Error", "RefChannel", "RefTopic", "RefPartition", "RefHash")
    MESSAGEID_FIELD_NUMBER: _ClassVar[int]
    SENTAT_FIELD_NUMBER: _ClassVar[int]
    EXPIRATIONAT_FIELD_NUMBER: _ClassVar[int]
    DELAYEDTO_FIELD_NUMBER: _ClassVar[int]
    ISERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    REFCHANNEL_FIELD_NUMBER: _ClassVar[int]
    REFTOPIC_FIELD_NUMBER: _ClassVar[int]
    REFPARTITION_FIELD_NUMBER: _ClassVar[int]
    REFHASH_FIELD_NUMBER: _ClassVar[int]
    MessageID: str
    SentAt: int
    ExpirationAt: int
    DelayedTo: int
    IsError: bool
    Error: str
    RefChannel: str
    RefTopic: str
    RefPartition: int
    RefHash: str
    def __init__(self, MessageID: _Optional[str] = ..., SentAt: _Optional[int] = ..., ExpirationAt: _Optional[int] = ..., DelayedTo: _Optional[int] = ..., IsError: bool = ..., Error: _Optional[str] = ..., RefChannel: _Optional[str] = ..., RefTopic: _Optional[str] = ..., RefPartition: _Optional[int] = ..., RefHash: _Optional[str] = ...) -> None: ...

class ReceiveQueueMessagesRequest(_message.Message):
    __slots__ = ("RequestID", "ClientID", "Channel", "MaxNumberOfMessages", "WaitTimeSeconds", "IsPeak")
    REQUESTID_FIELD_NUMBER: _ClassVar[int]
    CLIENTID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    MAXNUMBEROFMESSAGES_FIELD_NUMBER: _ClassVar[int]
    WAITTIMESECONDS_FIELD_NUMBER: _ClassVar[int]
    ISPEAK_FIELD_NUMBER: _ClassVar[int]
    RequestID: str
    ClientID: str
    Channel: str
    MaxNumberOfMessages: int
    WaitTimeSeconds: int
    IsPeak: bool
    def __init__(self, RequestID: _Optional[str] = ..., ClientID: _Optional[str] = ..., Channel: _Optional[str] = ..., MaxNumberOfMessages: _Optional[int] = ..., WaitTimeSeconds: _Optional[int] = ..., IsPeak: bool = ...) -> None: ...

class ReceiveQueueMessagesResponse(_message.Message):
    __slots__ = ("RequestID", "Messages", "MessagesReceived", "MessagesExpired", "IsPeak", "IsError", "Error")
    REQUESTID_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    MESSAGESRECEIVED_FIELD_NUMBER: _ClassVar[int]
    MESSAGESEXPIRED_FIELD_NUMBER: _ClassVar[int]
    ISPEAK_FIELD_NUMBER: _ClassVar[int]
    ISERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    RequestID: str
    Messages: _containers.RepeatedCompositeFieldContainer[QueueMessage]
    MessagesReceived: int
    MessagesExpired: int
    IsPeak: bool
    IsError: bool
    Error: str
    def __init__(self, RequestID: _Optional[str] = ..., Messages: _Optional[_Iterable[_Union[QueueMessage, _Mapping]]] = ..., MessagesReceived: _Optional[int] = ..., MessagesExpired: _Optional[int] = ..., IsPeak: bool = ..., IsError: bool = ..., Error: _Optional[str] = ...) -> None: ...

class AckAllQueueMessagesRequest(_message.Message):
    __slots__ = ("RequestID", "ClientID", "Channel", "WaitTimeSeconds")
    REQUESTID_FIELD_NUMBER: _ClassVar[int]
    CLIENTID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    WAITTIMESECONDS_FIELD_NUMBER: _ClassVar[int]
    RequestID: str
    ClientID: str
    Channel: str
    WaitTimeSeconds: int
    def __init__(self, RequestID: _Optional[str] = ..., ClientID: _Optional[str] = ..., Channel: _Optional[str] = ..., WaitTimeSeconds: _Optional[int] = ...) -> None: ...

class AckAllQueueMessagesResponse(_message.Message):
    __slots__ = ("RequestID", "AffectedMessages", "IsError", "Error")
    REQUESTID_FIELD_NUMBER: _ClassVar[int]
    AFFECTEDMESSAGES_FIELD_NUMBER: _ClassVar[int]
    ISERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    RequestID: str
    AffectedMessages: int
    IsError: bool
    Error: str
    def __init__(self, RequestID: _Optional[str] = ..., AffectedMessages: _Optional[int] = ..., IsError: bool = ..., Error: _Optional[str] = ...) -> None: ...

class StreamQueueMessagesRequest(_message.Message):
    __slots__ = ("RequestID", "ClientID", "StreamRequestTypeData", "Channel", "VisibilitySeconds", "WaitTimeSeconds", "RefSequence", "ModifiedMessage")
    REQUESTID_FIELD_NUMBER: _ClassVar[int]
    CLIENTID_FIELD_NUMBER: _ClassVar[int]
    STREAMREQUESTTYPEDATA_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    VISIBILITYSECONDS_FIELD_NUMBER: _ClassVar[int]
    WAITTIMESECONDS_FIELD_NUMBER: _ClassVar[int]
    REFSEQUENCE_FIELD_NUMBER: _ClassVar[int]
    MODIFIEDMESSAGE_FIELD_NUMBER: _ClassVar[int]
    RequestID: str
    ClientID: str
    StreamRequestTypeData: StreamRequestType
    Channel: str
    VisibilitySeconds: int
    WaitTimeSeconds: int
    RefSequence: int
    ModifiedMessage: QueueMessage
    def __init__(self, RequestID: _Optional[str] = ..., ClientID: _Optional[str] = ..., StreamRequestTypeData: _Optional[_Union[StreamRequestType, str]] = ..., Channel: _Optional[str] = ..., VisibilitySeconds: _Optional[int] = ..., WaitTimeSeconds: _Optional[int] = ..., RefSequence: _Optional[int] = ..., ModifiedMessage: _Optional[_Union[QueueMessage, _Mapping]] = ...) -> None: ...

class StreamQueueMessagesResponse(_message.Message):
    __slots__ = ("RequestID", "StreamRequestTypeData", "Message", "IsError", "Error")
    REQUESTID_FIELD_NUMBER: _ClassVar[int]
    STREAMREQUESTTYPEDATA_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ISERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    RequestID: str
    StreamRequestTypeData: StreamRequestType
    Message: QueueMessage
    IsError: bool
    Error: str
    def __init__(self, RequestID: _Optional[str] = ..., StreamRequestTypeData: _Optional[_Union[StreamRequestType, str]] = ..., Message: _Optional[_Union[QueueMessage, _Mapping]] = ..., IsError: bool = ..., Error: _Optional[str] = ...) -> None: ...

class QueuesUpstreamRequest(_message.Message):
    __slots__ = ("RequestID", "Messages")
    REQUESTID_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    RequestID: str
    Messages: _containers.RepeatedCompositeFieldContainer[QueueMessage]
    def __init__(self, RequestID: _Optional[str] = ..., Messages: _Optional[_Iterable[_Union[QueueMessage, _Mapping]]] = ...) -> None: ...

class QueuesUpstreamResponse(_message.Message):
    __slots__ = ("RefRequestID", "Results", "IsError", "Error")
    REFREQUESTID_FIELD_NUMBER: _ClassVar[int]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    ISERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    RefRequestID: str
    Results: _containers.RepeatedCompositeFieldContainer[SendQueueMessageResult]
    IsError: bool
    Error: str
    def __init__(self, RefRequestID: _Optional[str] = ..., Results: _Optional[_Iterable[_Union[SendQueueMessageResult, _Mapping]]] = ..., IsError: bool = ..., Error: _Optional[str] = ...) -> None: ...

class QueuesDownstreamRequest(_message.Message):
    __slots__ = ("RequestID", "ClientID", "RequestTypeData", "Channel", "MaxItems", "WaitTimeout", "AutoAck", "ReQueueChannel", "SequenceRange", "RefTransactionId", "Metadata")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    REQUESTID_FIELD_NUMBER: _ClassVar[int]
    CLIENTID_FIELD_NUMBER: _ClassVar[int]
    REQUESTTYPEDATA_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    MAXITEMS_FIELD_NUMBER: _ClassVar[int]
    WAITTIMEOUT_FIELD_NUMBER: _ClassVar[int]
    AUTOACK_FIELD_NUMBER: _ClassVar[int]
    REQUEUECHANNEL_FIELD_NUMBER: _ClassVar[int]
    SEQUENCERANGE_FIELD_NUMBER: _ClassVar[int]
    REFTRANSACTIONID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    RequestID: str
    ClientID: str
    RequestTypeData: QueuesDownstreamRequestType
    Channel: str
    MaxItems: int
    WaitTimeout: int
    AutoAck: bool
    ReQueueChannel: str
    SequenceRange: _containers.RepeatedScalarFieldContainer[int]
    RefTransactionId: str
    Metadata: _containers.ScalarMap[str, str]
    def __init__(self, RequestID: _Optional[str] = ..., ClientID: _Optional[str] = ..., RequestTypeData: _Optional[_Union[QueuesDownstreamRequestType, str]] = ..., Channel: _Optional[str] = ..., MaxItems: _Optional[int] = ..., WaitTimeout: _Optional[int] = ..., AutoAck: bool = ..., ReQueueChannel: _Optional[str] = ..., SequenceRange: _Optional[_Iterable[int]] = ..., RefTransactionId: _Optional[str] = ..., Metadata: _Optional[_Mapping[str, str]] = ...) -> None: ...

class QueuesDownstreamResponse(_message.Message):
    __slots__ = ("TransactionId", "RefRequestId", "RequestTypeData", "Messages", "ActiveOffsets", "IsError", "Error", "TransactionComplete", "Metadata")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    TRANSACTIONID_FIELD_NUMBER: _ClassVar[int]
    REFREQUESTID_FIELD_NUMBER: _ClassVar[int]
    REQUESTTYPEDATA_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    ACTIVEOFFSETS_FIELD_NUMBER: _ClassVar[int]
    ISERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    TRANSACTIONCOMPLETE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    TransactionId: str
    RefRequestId: str
    RequestTypeData: QueuesDownstreamRequestType
    Messages: _containers.RepeatedCompositeFieldContainer[QueueMessage]
    ActiveOffsets: _containers.RepeatedScalarFieldContainer[int]
    IsError: bool
    Error: str
    TransactionComplete: bool
    Metadata: _containers.ScalarMap[str, str]
    def __init__(self, TransactionId: _Optional[str] = ..., RefRequestId: _Optional[str] = ..., RequestTypeData: _Optional[_Union[QueuesDownstreamRequestType, str]] = ..., Messages: _Optional[_Iterable[_Union[QueueMessage, _Mapping]]] = ..., ActiveOffsets: _Optional[_Iterable[int]] = ..., IsError: bool = ..., Error: _Optional[str] = ..., TransactionComplete: bool = ..., Metadata: _Optional[_Mapping[str, str]] = ...) -> None: ...

class QueueInfo(_message.Message):
    __slots__ = ("Name", "Messages", "Bytes", "FirstSequence", "LastSequence", "Sent", "Delivered", "Waiting", "Subscribers")
    NAME_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    FIRSTSEQUENCE_FIELD_NUMBER: _ClassVar[int]
    LASTSEQUENCE_FIELD_NUMBER: _ClassVar[int]
    SENT_FIELD_NUMBER: _ClassVar[int]
    DELIVERED_FIELD_NUMBER: _ClassVar[int]
    WAITING_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIBERS_FIELD_NUMBER: _ClassVar[int]
    Name: str
    Messages: int
    Bytes: int
    FirstSequence: int
    LastSequence: int
    Sent: int
    Delivered: int
    Waiting: int
    Subscribers: int
    def __init__(self, Name: _Optional[str] = ..., Messages: _Optional[int] = ..., Bytes: _Optional[int] = ..., FirstSequence: _Optional[int] = ..., LastSequence: _Optional[int] = ..., Sent: _Optional[int] = ..., Delivered: _Optional[int] = ..., Waiting: _Optional[int] = ..., Subscribers: _Optional[int] = ...) -> None: ...

class QueuesInfo(_message.Message):
    __slots__ = ("TotalQueue", "Sent", "Delivered", "Waiting", "Queues")
    TOTALQUEUE_FIELD_NUMBER: _ClassVar[int]
    SENT_FIELD_NUMBER: _ClassVar[int]
    DELIVERED_FIELD_NUMBER: _ClassVar[int]
    WAITING_FIELD_NUMBER: _ClassVar[int]
    QUEUES_FIELD_NUMBER: _ClassVar[int]
    TotalQueue: int
    Sent: int
    Delivered: int
    Waiting: int
    Queues: _containers.RepeatedCompositeFieldContainer[QueueInfo]
    def __init__(self, TotalQueue: _Optional[int] = ..., Sent: _Optional[int] = ..., Delivered: _Optional[int] = ..., Waiting: _Optional[int] = ..., Queues: _Optional[_Iterable[_Union[QueueInfo, _Mapping]]] = ...) -> None: ...

class QueuesInfoRequest(_message.Message):
    __slots__ = ("RequestID", "QueueName")
    REQUESTID_FIELD_NUMBER: _ClassVar[int]
    QUEUENAME_FIELD_NUMBER: _ClassVar[int]
    RequestID: str
    QueueName: str
    def __init__(self, RequestID: _Optional[str] = ..., QueueName: _Optional[str] = ...) -> None: ...

class QueuesInfoResponse(_message.Message):
    __slots__ = ("RefRequestID", "Info")
    REFREQUESTID_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    RefRequestID: str
    Info: QueuesInfo
    def __init__(self, RefRequestID: _Optional[str] = ..., Info: _Optional[_Union[QueuesInfo, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from kubemq.grpc import kubemq_pb2 as kubemq_dot_grpc_dot_kubemq__pb2


class kubemqStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendEvent = channel.unary_unary(
                '/kubemq.kubemq/SendEvent',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.Event.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.Result.FromString,
                )
        self.SendEventsStream = channel.stream_stream(
                '/kubemq.kubemq/SendEventsStream',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.Event.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.Result.FromString,
                )
        self.SubscribeToEvents = channel.unary_stream(
                '/kubemq.kubemq/SubscribeToEvents',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.Subscribe.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.EventReceive.FromString,
                )
        self.SubscribeToRequests = channel.unary_stream(
                '/kubemq.kubemq/SubscribeToRequests',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.Subscribe.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.Request.FromString,
                )
        self.SendRequest = channel.unary_unary(
                '/kubemq.kubemq/SendRequest',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.Request.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.Response.FromString,
                )
        self.SendResponse = channel.unary_unary(
                '/kubemq.kubemq/SendResponse',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.Response.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.Empty.FromString,
                )
        self.SendQueueMessage = channel.unary_unary(
                '/kubemq.kubemq/SendQueueMessage',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.QueueMessage.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.SendQueueMessageResult.FromString,
                )
        self.SendQueueMessagesBatch = channel.unary_unary(
                '/kubemq.kubemq/SendQueueMessagesBatch',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.QueueMessagesBatchRequest.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.QueueMessagesBatchResponse.FromString,
                )
        self.ReceiveQueueMessages = channel.unary_unary(
                '/kubemq.kubemq/ReceiveQueueMessages',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.ReceiveQueueMessagesRequest.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.ReceiveQueueMessagesResponse.FromString,
                )
        self.StreamQueueMessage = channel.stream_stream(
                '/kubemq.kubemq/StreamQueueMessage',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.StreamQueueMessagesRequest.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.StreamQueueMessagesResponse.FromString,
                )
        self.AckAllQueueMessages = channel.unary_unary(
                '/kubemq.kubemq/AckAllQueueMessages',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.AckAllQueueMessagesRequest.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.AckAllQueueMessagesResponse.FromString,
                )
        self.Ping = channel.unary_unary(
                '/kubemq.kubemq/Ping',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.Empty.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.PingResult.FromString,
                )
        self.QueuesDownstream = channel.stream_stream(
                '/kubemq.kubemq/QueuesDownstream',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.QueuesDownstreamRequest.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.QueuesDownstreamResponse.FromString,
                )
        self.QueuesUpstream = channel.stream_stream(
                '/kubemq.kubemq/QueuesUpstream',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.QueuesUpstreamRequest.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.QueuesUpstreamResponse.FromString,
                )
        self.QueuesInfo = channel.unary_unary(
                '/kubemq.kubemq/QueuesInfo',
                request_serializer=kubemq_dot_grpc_dot_kubemq__pb2.QueuesInfoRequest.SerializeToString,
                response_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.QueuesInfoResponse.FromString,
                )


class kubemqServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SendEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendEventsStream(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeToEvents(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeToRequests(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendResponse(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendQueueMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendQueueMessagesBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReceiveQueueMessages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamQueueMessage(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AckAllQueueMessages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Ping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueuesDownstream(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueuesUpstream(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueuesInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_kubemqServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SendEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.SendEvent,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.Event.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.Result.SerializeToString,
            ),
            'SendEventsStream': grpc.stream_stream_rpc_method_handler(
                    servicer.SendEventsStream,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.Event.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.Result.SerializeToString,
            ),
            'SubscribeToEvents': grpc.unary_stream_rpc_method_handler(
                    servicer.SubscribeToEvents,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.Subscribe.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.EventReceive.SerializeToString,
            ),
            'SubscribeToRequests': grpc.unary_stream_rpc_method_handler(
                    servicer.SubscribeToRequests,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.Subscribe.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.Request.SerializeToString,
            ),
            'SendRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.SendRequest,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.Request.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.Response.SerializeToString,
            ),
            'SendResponse': grpc.unary_unary_rpc_method_handler(
                    servicer.SendResponse,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.Response.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.Empty.SerializeToString,
            ),
            'SendQueueMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.SendQueueMessage,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.QueueMessage.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.SendQueueMessageResult.SerializeToString,
            ),
            'SendQueueMessagesBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.SendQueueMessagesBatch,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.QueueMessagesBatchRequest.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.QueueMessagesBatchResponse.SerializeToString,
            ),
            'ReceiveQueueMessages': grpc.unary_unary_rpc_method_handler(
                    servicer.ReceiveQueueMessages,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.ReceiveQueueMessagesRequest.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.ReceiveQueueMessagesResponse.SerializeToString,
            ),
            'StreamQueueMessage': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamQueueMessage,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.StreamQueueMessagesRequest.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.StreamQueueMessagesResponse.SerializeToString,
            ),
            'AckAllQueueMessages': grpc.unary_unary_rpc_method_handler(
                    servicer.AckAllQueueMessages,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.AckAllQueueMessagesRequest.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.AckAllQueueMessagesResponse.SerializeToString,
            ),
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.Empty.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.PingResult.SerializeToString,
            ),
            'QueuesDownstream': grpc.stream_stream_rpc_method_handler(
                    servicer.QueuesDownstream,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.QueuesDownstreamRequest.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.QueuesDownstreamResponse.SerializeToString,
            ),
            'QueuesUpstream': grpc.stream_stream_rpc_method_handler(
                    servicer.QueuesUpstream,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.QueuesUpstreamRequest.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.QueuesUpstreamResponse.SerializeToString,
            ),
            'QueuesInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.QueuesInfo,
                    request_deserializer=kubemq_dot_grpc_dot_kubemq__pb2.QueuesInfoRequest.FromString,
                    response_serializer=kubemq_dot_grpc_dot_kubemq__pb2.QueuesInfoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kubemq.kubemq', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class kubemq(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SendEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kubemq.kubemq/SendEvent',
            kubemq_dot_grpc_dot_kubemq__pb2.Event.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendEventsStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/kubemq.kubemq/SendEventsStream',
            kubemq_dot_grpc_dot_kubemq__pb2.Event.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubscribeToEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kubemq.kubemq/SubscribeToEvents',
            kubemq_dot_grpc_dot_kubemq__pb2.Subscribe.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.EventReceive.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubscribeToRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/kubemq.kubemq/SubscribeToRequests',
            kubemq_dot_grpc_dot_kubemq__pb2.Subscribe.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.Request.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kubemq.kubemq/SendRequest',
            kubemq_dot_grpc_dot_kubemq__pb2.Request.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendResponse(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kubemq.kubemq/SendResponse',
            kubemq_dot_grpc_dot_kubemq__pb2.Response.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendQueueMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kubemq.kubemq/SendQueueMessage',
            kubemq_dot_grpc_dot_kubemq__pb2.QueueMessage.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.SendQueueMessageResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendQueueMessagesBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kubemq.kubemq/SendQueueMessagesBatch',
            kubemq_dot_grpc_dot_kubemq__pb2.QueueMessagesBatchRequest.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.QueueMessagesBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReceiveQueueMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kubemq.kubemq/ReceiveQueueMessages',
            kubemq_dot_grpc_dot_kubemq__pb2.ReceiveQueueMessagesRequest.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.ReceiveQueueMessagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamQueueMessage(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/kubemq.kubemq/StreamQueueMessage',
            kubemq_dot_grpc_dot_kubemq__pb2.StreamQueueMessagesRequest.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.StreamQueueMessagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AckAllQueueMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kubemq.kubemq/AckAllQueueMessages',
            kubemq_dot_grpc_dot_kubemq__pb2.AckAllQueueMessagesRequest.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.AckAllQueueMessagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kubemq.kubemq/Ping',
            kubemq_dot_grpc_dot_kubemq__pb2.Empty.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.PingResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueuesDownstream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/kubemq.kubemq/QueuesDownstream',
            kubemq_dot_grpc_dot_kubemq__pb2.QueuesDownstreamRequest.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.QueuesDownstreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueuesUpstream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/kubemq.kubemq/QueuesUpstream',
            kubemq_dot_grpc_dot_kubemq__pb2.QueuesUpstreamRequest.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.QueuesUpstreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueuesInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/kubemq.kubemq/QueuesInfo',
            kubemq_dot_grpc_dot_kubemq__pb2.QueuesInfoRequest.SerializeToString,
            kubemq_dot_grpc_dot_kubemq__pb2.QueuesInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from kubemq.transport.keep_alive import KeepAliveConfig
from kubemq.transport.tls_config import TlsConfig


class Connection:
    """

    The `Connection` class represents a connection object that can be used to establish and manage a connection to a remote server.

    Attributes:
        DEFAULT_MAX_SEND_SIZE (int): The default maximum size for sending data (100MB).
        DEFAULT_MAX_RCV_SIZE (int): The default maximum size for receiving data (100MB).
        DEFAULT_RECONNECT_INTERVAL_SECONDS (int): The default interval in seconds for reconnecting to the server (5 seconds).

    __init__ method:
        Initializes a new instance of the Connection class.

        Parameters:
            address (str): The address of the remote server.
            client_id (str): The client ID.
            auth_token (str): The authentication token.
            max_send_size (int): The maximum size for sending data.
            max_receive_size (int): The maximum size for receiving data.
            disable_auto_reconnect (bool): Flag indicating whether auto reconnect is disabled.
            reconnect_interval_seconds (int): The interval in seconds for reconnecting to the server.
            tls (TlsConfig): The TLS configuration.
            keep_alive (KeepAliveConfig): The keep-alive configuration.

    address property:
        Gets or sets the address of the remote server.

    client_id property:
        Gets or sets the client ID.

    auth_token property:
        Gets or sets the authentication token.

    max_send_size property:
        Gets or sets the maximum size for sending data.

    max_receive_size property:
        Gets or sets the maximum size for receiving data.

    disable_auto_reconnect property:
        Gets or sets a flag indicating whether auto reconnect is disabled.

    reconnect_interval_seconds property:
        Gets or sets the interval in seconds for reconnecting to the server.

    tls property:
        Gets or sets the TLS configuration.

    keep_alive property:
        Gets or sets the keep-alive configuration.

    get_reconnect_interval_duration method:
        Gets the reconnect interval duration in milliseconds.

    complete method:
        Completes the connection by setting default values for certain properties if they are not already set.

    validate method:
        Validates the connection by checking if all required properties are set and if the values of certain properties are valid.

    Note: Please make sure to call the `validate` method before establishing a connection to ensure all required properties are set and valid.

    """
    DEFAULT_MAX_SEND_SIZE = 1024 * 1024 * 100  # 100MB
    DEFAULT_MAX_RCV_SIZE = 1024 * 1024 * 100  # 100MB
    DEFAULT_RECONNECT_INTERVAL_SECONDS = 5

    def __init__(self, address: str = "", client_id: str = "", auth_token: str = "",
                 max_send_size: int = DEFAULT_MAX_SEND_SIZE,
                 max_receive_size: int = DEFAULT_MAX_RCV_SIZE,
                 disable_auto_reconnect: bool = False,
                 reconnect_interval_seconds: int = DEFAULT_RECONNECT_INTERVAL_SECONDS,
                 tls: TlsConfig = None,
                 keep_alive: KeepAliveConfig = None,
                 log_level: int = None) -> None:
        self._address: str = address
        self._client_id: str = client_id
        self._auth_token: str = auth_token
        self._max_send_size: int = max_send_size
        self._max_receive_size: int = max_receive_size
        self._disable_auto_reconnect: bool = disable_auto_reconnect
        self._reconnect_interval_seconds: int = reconnect_interval_seconds
        self._tls: TlsConfig = tls if tls else TlsConfig()
        self._keep_alive: KeepAliveConfig = keep_alive if keep_alive else KeepAliveConfig()
        self._log_level: int = log_level

    @property
    def address(self) -> str:
        return self._address

    @address.setter
    def address(self, value: str) -> None:
        self._address = value

    @property
    def client_id(self) -> str:
        return self._client_id

    @client_id.setter
    def client_id(self, value: str) -> None:
        self._client_id = value

    @property
    def auth_token(self) -> str:
        return self._auth_token

    @auth_token.setter
    def auth_token(self, value: str) -> None:
        self._auth_token = value

    @property
    def max_send_size(self) -> int:
        return self._max_send_size

    @max_send_size.setter
    def max_send_size(self, value: int) -> None:
        self._max_send_size = value

    @property
    def max_receive_size(self) -> int:
        return self._max_receive_size

    @max_receive_size.setter
    def max_receive_size(self, value: int) -> None:
        self._max_receive_size = value

    @property
    def disable_auto_reconnect(self) -> bool:
        return self._disable_auto_reconnect

    @disable_auto_reconnect.setter
    def disable_auto_reconnect(self, value: bool) -> None:
        self._disable_auto_reconnect = value

    @property
    def reconnect_interval_seconds(self) -> int:
        return self._reconnect_interval_seconds

    @reconnect_interval_seconds.setter
    def reconnect_interval_seconds(self, value: int) -> None:
        self._reconnect_interval_seconds = value

    @property
    def tls(self) -> TlsConfig:
        return self._tls

    @tls.setter
    def tls(self, value: TlsConfig) -> None:
        self._tls = value

    @property
    def keep_alive(self) -> KeepAliveConfig:
        return self._keep_alive

    @keep_alive.setter
    def keep_alive(self, value: KeepAliveConfig) -> None:
        self._keep_alive = value

    def get_reconnect_interval_duration(self) -> int:
        return self._reconnect_interval_seconds * 1000

    def set_log_level(self, value: int) -> 'Connection':
        self._log_level = value
        return self

    def complete(self) -> 'Connection':
        if self._max_send_size == 0:
            self._max_send_size = self.DEFAULT_MAX_SEND_SIZE
        if self._max_receive_size == 0:
            self._max_receive_size = self.DEFAULT_MAX_RCV_SIZE
        if self._reconnect_interval_seconds == 0:
            self._reconnect_interval_seconds = self.DEFAULT_RECONNECT_INTERVAL_SECONDS
        return self

    def validate(self) -> None:
        if not self._address:
            raise ValueError("Connection must have an address")
        if not self._client_id:
            raise ValueError("Connection must have a client_id")
        if self._max_send_size < 0:
            raise ValueError("Connection max send size must be greater than 0")
        if self._max_receive_size < 0:
            raise ValueError("Connection max receive size must be greater than 0")
        if self._reconnect_interval_seconds < 0:
            raise ValueError("Connection reconnect interval must be greater than 0")
        if self._tls is not None:
            self._tls.validate()
        if self._keep_alive is not None:
            self._keep_alive.validate()



class ServerInfo:
    """

    The ServerInfo class represents information about a server.

    Attributes:
        _host (str): The host of the server.
        _version (str): The version of the server.
        _server_start_time (int): The start time of the server (in seconds).
        _server_up_time_seconds (int): The uptime of the server (in seconds).

    Methods:
        host (property): Getter and setter for the _host attribute.
        version (property): Getter and setter for the _version attribute.
        server_start_time (property): Getter and setter for the _server_start_time attribute.
        server_up_time_seconds (property): Getter and setter for the _server_up_time_seconds attribute.
        __str__(): Returns a string representation of the ServerInfo object.

    """
    def __init__(self, host: str, version: str, server_start_time: int, server_up_time_seconds: int):
        self._host = host
        self._version = version
        self._server_start_time = server_start_time
        self._server_up_time_seconds = server_up_time_seconds

    @property
    def host(self) -> str:
        return self._host

    @host.setter
    def host(self, value: str) -> None:
        self._host = value

    @property
    def version(self) -> str:
        return self._version

    @version.setter
    def version(self, value: str) -> None:
        self._version = value

    @property
    def server_start_time(self) -> int:
        return self._server_start_time

    @server_start_time.setter
    def server_start_time(self, value: int) -> None:
        """

        """
        self._server_start_time = value

    @property
    def server_up_time_seconds(self) -> int:
        return self._server_up_time_seconds

    @server_up_time_seconds.setter
    def server_up_time_seconds(self, value: int) -> None:
        self._server_up_time_seconds = value

    def __str__(self):
        return (f"ServerInfo(host={self._host}, version={self._version}, "
                f"server_start_time={self._server_start_time}, server_up_time_seconds={self._server_up_time_seconds})")



from pydantic import BaseModel, Field
from typing import List, Callable, Optional
import uuid
from kubemq.grpc import (
    QueuesDownstreamRequest,
    QueuesDownstreamResponse,
    QueuesDownstreamRequestType,
)
from kubemq.queues.queues_message_received import QueueMessageReceived


class QueuesPollResponse(BaseModel):
    ref_request_id: str = Field(default="")
    transaction_id: str = Field(default="")
    messages: List[QueueMessageReceived] = Field(default_factory=list)
    error: str = Field(default="")
    is_error: bool = Field(default=False)
    is_transaction_completed: bool = Field(default=False)
    active_offsets: List[int] = Field(default_factory=list)
    receiver_client_id: str = Field(default="")
    response_handler: Optional[
        Callable[[QueuesDownstreamRequest], QueuesDownstreamResponse]
    ] = Field(default=None)

    def ack_all(self):
        if self.is_transaction_completed:
            raise ValueError("transaction is already completed")
        request = QueuesDownstreamRequest()
        request.RequestID = str(uuid.uuid4())
        request.ClientID = self.receiver_client_id
        request.RequestTypeData = QueuesDownstreamRequestType.AckAll
        request.RefTransactionId = self.transaction_id
        request.SequenceRange.extend(self.active_offsets)
        if self.response_handler:
            self.response_handler(request)
        else:
            raise ValueError("response_handler is not set")

    def reject_all(self):
        if self.is_transaction_completed:
            raise ValueError("transaction is already completed")
        request = QueuesDownstreamRequest()
        request.RequestID = str(uuid.uuid4())
        request.ClientID = self.receiver_client_id
        request.RequestTypeData = QueuesDownstreamRequestType.NAckAll
        request.RefTransactionId = self.transaction_id
        request.SequenceRange.extend(self.active_offsets)
        if self.response_handler:
            result = self.response_handler(request)
            if result.IsError:
                raise ValueError(result.Error)
        else:
            raise ValueError("response_handler is not set")

    def re_queue_all(self, channel: str):
        if not channel:
            raise ValueError("re-queue channel cannot be empty")
        request = QueuesDownstreamRequest()
        request.RequestID = str(uuid.uuid4())
        request.ClientID = self.receiver_client_id
        request.RequestTypeData = QueuesDownstreamRequestType.ReQueueAll
        request.RefTransactionId = self.transaction_id
        request.SequenceRange.extend(self.active_offsets)
        request.ReQueueChannel = channel
        if self.response_handler:
            result = self.response_handler(request)
            if result.IsError:
                raise ValueError(result.Error)
        else:
            raise ValueError("response_handler is not set")

    @classmethod
    def decode(
        cls,
        response: QueuesDownstreamResponse,
        receiver_client_id: str,
        response_handler: Callable[[QueuesDownstreamRequest], QueuesDownstreamResponse],
    ) -> "QueuesPollResponse":
        messages = [
            QueueMessageReceived.decode(
                message,
                response.TransactionId,
                response.TransactionComplete,
                receiver_client_id,
                response_handler,
            )
            for message in response.Messages
        ]

        return cls(
            ref_request_id=response.RefRequestId,
            transaction_id=response.TransactionId,
            messages=messages,
            error=response.Error,
            is_error=response.IsError,
            is_transaction_completed=response.TransactionComplete,
            active_offsets=list(response.ActiveOffsets),
            receiver_client_id=receiver_client_id,
            response_handler=response_handler,
        )

    class Config:
        arbitrary_types_allowed = True



import logging
import threading
import queue
import time
import grpc
from kubemq.transport import Transport, Connection
from kubemq.grpc import QueuesUpstreamRequest, QueuesUpstreamResponse, SendQueueMessageResult
from kubemq.common import *
from kubemq.queues import *
class UpstreamSender:
    """

    UpstreamSender

    Class representing an upstream sender for sending messages to a server.

    Attributes:
        clientStub (Transport): The transport object used for communication with the server.
        connection (Connection): The connection object representing the client's connection to the server.
        shutdown_event (threading.Event): The event object used to signal the shutdown of the sender.
        logger (logging.Logger): The logger object used for logging.
        lock (threading.Lock): The lock used to synchronize access to shared resources.
        response_tracking (dict): A dictionary mapping request IDs to response containers, response result events, and message IDs.
        sending_queue (queue.Queue): The queue used for storing messages to be sent.
        allow_new_messages (bool): A flag indicating if new messages are allowed to be sent.

    Methods:
        send(message: QueueMessage) -> [QueueSendResult, None]:
            Sends a message to the server.

        _handle_disconnection():
            Handles the disconnection from the server.

        _send_queue_stream():
            Sends messages from the sending queue to the server.

    """
    def __init__(self, transport: Transport, shutdown_event: threading.Event, logger: logging.Logger,
                 connection: Connection):
        self.clientStub = transport.kubemq_client()
        self.connection = connection
        self.shutdown_event = shutdown_event
        self.logger = logger
        self.lock = threading.Lock()
        self.response_tracking = {}
        self.sending_queue = queue.Queue()
        self.allow_new_messages = True
        threading.Thread(target=self._send_queue_stream, args=(), daemon=True).start()

    def send(self, message: QueueMessage) -> [QueueSendResult, None]:
        if not self.allow_new_messages:
            raise ConnectionError("Client is not connected to the server and cannot send messages.")
        response_result = threading.Event()
        response_container = {}
        message_id = message.id
        queue_upstream_request = message.encode(self.connection.client_id)
        with self.lock:
            self.response_tracking[queue_upstream_request.RequestID] = (
                response_container, response_result, message_id)
        self.sending_queue.put(queue_upstream_request)
        response_result.wait()
        response: QueuesUpstreamResponse = response_container.get('response')
        with self.lock:
            if response is not None:
                del self.response_tracking[queue_upstream_request.RequestID]
        if response is None or len(response.Results) == 0:
            return None
        send_result = response.Results[0]
        return QueueSendResult().decode(send_result)

    def _handle_disconnection(self):
        with self.lock:
            self.allow_new_messages = False
            while not self.sending_queue.empty():
                try:
                    self.sending_queue.get_nowait()  # Clear the queue
                except queue.Empty:
                    continue

            # Set error on all response containers
            for request_id, (response_container, response_result, message_id) in self.response_tracking.items():
                response_container['response'] = QueuesUpstreamResponse(
                    RefRequestID=request_id,
                    Results=[SendQueueMessageResult(
                        MessageID=message_id,
                        IsError=True,
                        Error="Error: Disconnected from server"
                    )]
                )
                response_result.set()  # Signal that the response has been processed
            self.response_tracking.clear()

    def _send_queue_stream(self):
        def send_requests():
            while not self.shutdown_event.is_set():
                try:
                    msg = self.sending_queue.get(timeout=1)  # timeout to check for shutdown event periodically
                    yield msg
                except queue.Empty:
                    continue

        while not self.shutdown_event.is_set():
            try:
                with self.lock:
                    self.allow_new_messages = True
                responses = self.clientStub.QueuesUpstream(send_requests())
                for response in responses:
                    if self.shutdown_event.is_set():
                        break
                    response_request_id = response.RefRequestID
                    with self.lock:
                        if response_request_id in self.response_tracking:
                            response_container, response_result, message_od = self.response_tracking[
                                response_request_id]
                            response_container['response'] = response
                            response_result.set()
            except grpc.RpcError as e:
                self.logger.debug(decode_grpc_error(e))
                self._handle_disconnection()
                time.sleep(self.connection.reconnect_interval_seconds)
                continue
            except Exception as e:
                self.logger.debug(f"Error: {str(e)}")
                self._handle_disconnection()
                time.sleep(self.connection.reconnect_interval_seconds)
                continue



import os

class TlsConfig:
    """

    Class TlsConfig handles the configuration settings for TLS (Transport Layer Security) encryption. It provides properties for enabling/disabling TLS, setting the certificate file, key
    * file, and CA (Certificate Authority) file.

    Attributes:
        _enabled (bool): Indicates whether TLS is enabled or not.
        _cert_file (str): Path to the TLS certificate file.
        _key_file (str): Path to the TLS private key file.
        _ca_file (str): Path to the TLS CA (Certificate Authority) file.

    Methods:
        __init__(self, enabled: bool = False, cert_file: str = "", key_file: str = "", ca_file: str = "") -> None:
            Initializes a new instance of TlsConfig with the given configuration settings.

            Args:
                enabled (bool): Indicates whether TLS is enabled or not. Default is False.
                cert_file (str): Path to the TLS certificate file. Default is an empty string.
                key_file (str): Path to the TLS private key file. Default is an empty string.
                ca_file (str): Path to the TLS CA (Certificate Authority) file. Default is an empty string.

        enabled(self) -> bool:
            Gets the value indicating whether TLS is enabled or not.

            Returns:
                bool: True if TLS is enabled, False otherwise.

        enabled(self, value: bool) -> None:
            Sets the value indicating whether TLS is enabled or not.

            Args:
                value (bool): True to enable TLS, False to disable.

        cert_file(self) -> str:
            Gets the path to the TLS certificate file.

            Returns:
                str: The path to the certificate file.

        cert_file(self, value: str) -> None:
            Sets the path to the TLS certificate file.

            Args:
                value (str): The path to the certificate file.

        key_file(self) -> str:
            Gets the path to the TLS private key file.

            Returns:
                str: The path to the private key file.

        key_file(self, value: str) -> None:
            Sets the path to the TLS private key file.

            Args:
                value (str): The path to the private key file.

        ca_file(self) -> str:
            Gets the path to the TLS CA (Certificate Authority) file.

            Returns:
                str: The path to the CA file.

        ca_file(self, value: str) -> None:
            Sets the path to the TLS CA (Certificate Authority) file.

            Args:
                value (str): The path to the CA file.

        validate(self) -> None:
            Performs validation on the TLS configuration settings. Raises FileNotFoundError if any of the specified files (certificate, key, or CA) do not exist.

    """
    def __init__(self, enabled: bool = False,
                 cert_file: str = "",
                 key_file: str = "",
                 ca_file: str = "") -> None:
        self._enabled: bool = enabled
        self._cert_file: str = cert_file
        self._key_file: str = key_file
        self._ca_file: str = ca_file

    @property
    def enabled(self) -> bool:
        return self._enabled

    @enabled.setter
    def enabled(self, value: bool) -> None:
        self._enabled = value

    @property
    def cert_file(self) -> str:
        return self._cert_file

    @cert_file.setter
    def cert_file(self, value: str) -> None:
        self._cert_file = value

    @property
    def key_file(self) -> str:
        return self._key_file

    @key_file.setter
    def key_file(self, value: str) -> None:
        self._key_file = value

    @property
    def ca_file(self) -> str:
        return self._ca_file

    @ca_file.setter
    def ca_file(self, value: str) -> None:
        self._ca_file = value

    def validate(self) -> None:
        if self._enabled:
            if self._cert_file and not os.path.isfile(self._cert_file):
                raise FileNotFoundError(f"The certificate file was not found: {self._cert_file}")

            if self._key_file and not os.path.isfile(self._key_file):
                raise FileNotFoundError(f"The key file was not found: {self._key_file}")

            if self._ca_file and not os.path.isfile(self._ca_file):
                raise FileNotFoundError(f"The CA file was not found: {self._ca_file}")



import logging
import threading
import queue
import time
import grpc
from kubemq.transport import Transport, Connection
from kubemq.grpc import QueuesDownstreamRequest, QueuesDownstreamResponse
from kubemq.common import *

class DownstreamReceiver:
    """
    Class representing a downstream receiver for sending requests to a server.

    Attributes:
        clientStub (Transport): The transport client stub.
        connection (Connection): The connection to the server.
        shutdown_event (threading.Event): The event used to indicate shutdown.
        logger (logging.Logger): The logger for logging messages.
        lock (threading.Lock): The lock used for thread safety.
        response_tracking (dict): A dictionary for tracking response containers and result events.
        queue (queue.Queue): The queue used for storing requests.
        allow_new_requests (bool): Flag indicating whether new requests are allowed.

    Methods:
        send(request: QueuesDownstreamRequest) -> [QueuesDownstreamResponse, None]:
            Sends a request to the server and waits for a response.

            Args:
                request (QueuesDownstreamRequest): The request to send.

            Returns:
                [QueuesDownstreamResponse, None]: The response from the server, or None if an exception occurred.

        send_without_response(request: QueuesDownstreamRequest):
            Sends a request to the server without waiting for a response.

            Args:
                request (QueuesDownstreamRequest): The request to send.

        _handle_disconnection():
            Handles disconnection from the server by clearing the queue and setting error on response containers.

        _send_queue_stream():
            Continuously sends requests from the queue to the server and handles responses.

    """
    def __init__(self, transport: Transport, shutdown_event: threading.Event, logger: logging.Logger,
                 connection: Connection):
        self.clientStub = transport.kubemq_client()
        self.connection = connection
        self.shutdown_event = shutdown_event
        self.logger = logger
        self.lock = threading.Lock()
        self.response_tracking = {}
        self.queue = queue.Queue()
        self.allow_new_requests = True
        threading.Thread(target=self._send_queue_stream, args=(), daemon=True).start()

    def send(self, request: QueuesDownstreamRequest) -> [QueuesDownstreamResponse, None]:
        try:
            if not self.allow_new_requests:
                raise ConnectionError("Client is not connected to the server and cannot accept new requests")
            response_result = threading.Event()
            response_container = {}
            with self.lock:
                self.response_tracking[request.RequestID] = (response_container, response_result)
            self.queue.put(request)
            response_result.wait()
            response: QueuesDownstreamResponse = response_container.get('response')
            with self.lock:
                if response is not None:
                    if self.response_tracking.get(request.RequestID):
                        del self.response_tracking[request.RequestID]

            return response
        except Exception as e:
            return QueuesDownstreamResponse(
                RefRequestId=request.RequestID,
                IsError=True,
                Error=str(e)
            )

    def send_without_response(self, request: QueuesDownstreamRequest):
        if not self.allow_new_requests:
            raise ConnectionError("Client is not connected to the server and cannot accept new requests")
        self.queue.put(request)

    def _handle_disconnection(self):
        with self.lock:
            self.allow_new_requests = False
            while not self.queue.empty():
                try:
                    self.queue.get_nowait()  # Clear the queue
                except queue.Empty:
                    continue

            # Set error on all response containers
            for request_id, (response_container, response_result) in self.response_tracking.items():
                response_container['response'] = QueuesDownstreamResponse(
                    RefRequestId=request_id,
                    IsError=True,
                    Error="Error: Disconnected from server"
                )
                response_result.set()  # Signal that the response has been processed
            self.response_tracking.clear()

    def _send_queue_stream(self):
        def send_requests():
            while not self.shutdown_event.is_set():
                try:
                    msg = self.queue.get(timeout=1)  # timeout to check for shutdown event periodically
                    yield msg
                except queue.Empty:
                    continue

        while not self.shutdown_event.is_set():
            try:
                with self.lock:
                    self.allow_new_requests = True
                responses = self.clientStub.QueuesDownstream(send_requests())
                for response in responses:
                    if self.shutdown_event.is_set():
                        break
                    response_request_id = response.RefRequestId
                    with self.lock:
                        if response_request_id in self.response_tracking:
                            response_container, response_result = self.response_tracking[
                                response_request_id]
                            response_container['response'] = response
                            response_result.set()
            except grpc.RpcError as e:
                self.logger.debug(decode_grpc_error(e))
                self._handle_disconnection()
                time.sleep(self.connection.reconnect_interval_seconds)
                continue
            except Exception as e:
                self.logger.debug(f"Error: {str(e)}")
                self._handle_disconnection()
                time.sleep(self.connection.reconnect_interval_seconds)
                continue



from pydantic import BaseModel, Field
from typing import Optional
from datetime import datetime
from kubemq.grpc import SendQueueMessageResult


class QueueSendResult(BaseModel):
    """
    QueueSendResult represents the result of sending a message to a queue.

    Attributes:
        id (str): The unique identifier of the message.
        sent_at (datetime): The timestamp when the message was sent.
        expired_at (datetime): The timestamp when the message will expire.
        delayed_to (datetime): The timestamp when the message will be delivered.
        is_error (bool): Indicates if there was an error while sending the message.
        error (str): The error message if `is_error` is True.
    """

    id: Optional[str] = Field(
        default=None, description="The unique identifier of the message"
    )
    sent_at: Optional[datetime] = Field(
        default=None, description="The timestamp when the message was sent"
    )
    expired_at: Optional[datetime] = Field(
        default=None, description="The timestamp when the message will expire"
    )
    delayed_to: Optional[datetime] = Field(
        default=None, description="The timestamp when the message will be delivered"
    )
    is_error: bool = Field(
        default=False,
        description="Indicates if there was an error while sending the message",
    )
    error: Optional[str] = Field(
        default=None, description="The error message if `is_error` is True"
    )

    @classmethod
    def decode(cls, result: SendQueueMessageResult) -> "QueueSendResult":
        return cls(
            id=result.MessageID if result.MessageID else None,
            sent_at=(
                datetime.fromtimestamp(result.SentAt / 1e9)
                if result.SentAt > 0
                else None
            ),
            expired_at=(
                datetime.fromtimestamp(result.ExpirationAt / 1e9)
                if result.ExpirationAt > 0
                else None
            ),
            delayed_to=(
                datetime.fromtimestamp(result.DelayedTo / 1e9)
                if result.DelayedTo > 0
                else None
            ),
            is_error=result.IsError if result.IsError else False,
            error=result.Error if result.Error else None,
        )

    class Config:
        arbitrary_types_allowed = True



import logging
from kubemq.queues import *


def main():
    with Client(address="localhost:50000") as client:
        send_result = client.send_queues_message(
            QueueMessage(
                channel="q1",
                body=b"some-simple_queue-queue-message",
                metadata="some-metadata",
            )
        )
        print(f"Queue Message Sent: {send_result}")

        result = client.receive_queues_messages(
            channel="q1",
            max_messages=1,
            wait_timeout_in_seconds=10,
            auto_ack=False,
        )
        result.ack_all()
        # if result.is_error:
        #     print(f"{result.error}")
        #     return
        # for message in result.messages:
        #     print(f"Id:{message.id}, Body:{message.body.decode('utf-8')}")
        #     message.ack()


if __name__ == "__main__":
    main()



from pydantic import BaseModel, Field, field_validator, model_validator
from typing import Dict, Optional
import uuid
from kubemq.grpc import QueueMessage as pbQueueMessage
from kubemq.grpc import QueuesUpstreamRequest as pbQueuesUpstreamRequest


class QueueMessage(BaseModel):
    """A class representing a message in a queue."""

    id: Optional[str] = Field(
        default=None, description="The unique identifier for the message"
    )
    channel: str = Field(..., description="The channel of the message")
    metadata: Optional[str] = Field(
        default=None, description="The metadata associated with the message"
    )
    body: bytes = Field(default=b"", description="The body of the message")
    tags: Dict[str, str] = Field(
        default_factory=dict, description="The tags associated with the message"
    )
    delay_in_seconds: int = Field(
        default=0,
        ge=0,
        description="The delay in seconds before the message becomes available in the queue",
    )
    expiration_in_seconds: int = Field(
        default=0, ge=0, description="The expiration time in seconds for the message"
    )
    attempts_before_dead_letter_queue: int = Field(
        default=0,
        ge=0,
        description="The number of receive attempts allowed for the message before it is moved to the dead letter queue",
    )
    dead_letter_queue: str = Field(
        default="",
        description="The dead letter queue where the message will be moved after reaching the maximum receive attempts",
    )

    @field_validator("channel")
    def channel_must_not_be_empty(cls, v: str) -> str:
        if not v:
            raise ValueError("Queue message must have a channel.")
        return v

    @model_validator(mode="after")
    def check_message_content(self) -> "QueueMessage":
        if not self.metadata and not self.body and not self.tags:
            raise ValueError(
                "Queue message must have at least one of the following: metadata, body, or tags."
            )
        return self

    def encode(self, client_id: str) -> pbQueuesUpstreamRequest:
        pb_queue_stream = pbQueuesUpstreamRequest()
        pb_queue_stream.RequestID = str(uuid.uuid4())
        pb_message = self.encode_message(client_id)
        pb_queue_stream.Messages.append(pb_message)
        return pb_queue_stream

    def encode_message(self, client_id: str) -> pbQueueMessage:
        pb_queue = pbQueueMessage()
        pb_queue.MessageID = self.id or str(uuid.uuid4())
        pb_queue.ClientID = client_id
        pb_queue.Channel = self.channel
        pb_queue.Metadata = self.metadata or ""
        pb_queue.Body = self.body
        pb_queue.Tags.update(self.tags)
        pb_queue.Policy.DelaySeconds = self.delay_in_seconds
        pb_queue.Policy.ExpirationSeconds = self.expiration_in_seconds
        pb_queue.Policy.MaxReceiveCount = self.attempts_before_dead_letter_queue
        pb_queue.Policy.MaxReceiveQueue = self.dead_letter_queue
        return pb_queue

    class Config:
        arbitrary_types_allowed = True



from pydantic import BaseModel, Field
from typing import Dict, Callable, Optional
from datetime import datetime
from kubemq.grpc import QueueMessage as pbQueueMessage
from kubemq.grpc import (
    QueuesDownstreamRequest,
    QueuesDownstreamRequestType,
    QueuesDownstreamResponse,
)
import uuid


class QueueMessageReceived(BaseModel):
    id: str = Field(default="")
    channel: str = Field(default="")
    metadata: str = Field(default="")
    body: bytes = Field(default=b"")
    from_client_id: str = Field(default="")
    tags: Dict[str, str] = Field(default_factory=dict)
    timestamp: datetime = Field(default_factory=lambda: datetime.fromtimestamp(0))
    sequence: int = Field(default=0)
    receive_count: int = Field(default=0)
    is_re_routed: bool = Field(default=False)
    re_route_from_queue: str = Field(default="")
    expired_at: datetime = Field(default_factory=lambda: datetime.fromtimestamp(0))
    delayed_to: datetime = Field(default_factory=lambda: datetime.fromtimestamp(0))
    transaction_id: str = Field(default="")
    is_transaction_completed: bool = Field(default=False)
    receiver_client_id: str = Field(default="")
    response_handler: Optional[
        Callable[[QueuesDownstreamRequest], QueuesDownstreamResponse]
    ] = Field(default=None)

    def ack(self):
        if self.is_transaction_completed:
            raise ValueError("transaction is already completed")
        request = QueuesDownstreamRequest()
        request.RequestID = str(uuid.uuid4())
        request.ClientID = self.receiver_client_id
        request.Channel = self.channel
        request.RequestTypeData = QueuesDownstreamRequestType.AckRange
        request.RefTransactionId = self.transaction_id
        request.SequenceRange.append(self.sequence)
        if self.response_handler:
            self.response_handler(request)
        else:
            raise ValueError("response_handler is not set")

    def reject(self):
        if self.is_transaction_completed:
            raise ValueError("transaction is already completed")
        request = QueuesDownstreamRequest()
        request.RequestID = str(uuid.uuid4())
        request.ClientID = self.receiver_client_id
        request.Channel = self.channel
        request.RequestTypeData = QueuesDownstreamRequestType.NAckRange
        request.RefTransactionId = self.transaction_id
        request.SequenceRange.append(self.sequence)
        if self.response_handler:
            self.response_handler(request)
        else:
            raise ValueError("response_handler is not set")

    def re_queue(self, channel: str):
        if not channel:
            raise ValueError("re-queue channel cannot be empty")
        request = QueuesDownstreamRequest()
        request.RequestID = str(uuid.uuid4())
        request.ClientID = self.receiver_client_id
        request.Channel = self.channel
        request.RequestTypeData = QueuesDownstreamRequestType.ReQueueRange
        request.RefTransactionId = self.transaction_id
        request.SequenceRange.append(self.sequence)
        request.ReQueueChannel = channel
        if self.response_handler:
            self.response_handler(request)
        else:
            raise ValueError("response_handler is not set")

    @classmethod
    def decode(
        cls,
        message: pbQueueMessage,
        transaction_id: str,
        transaction_is_completed: bool,
        receiver_client_id: str,
        response_handler: Callable[[QueuesDownstreamRequest], QueuesDownstreamResponse],
    ) -> "QueueMessageReceived":
        return cls(
            id=message.MessageID,
            channel=message.Channel,
            metadata=message.Metadata,
            body=message.Body,
            from_client_id=message.ClientID,
            tags={tag: message.Tags[tag] for tag in message.Tags},
            timestamp=(
                datetime.fromtimestamp(message.Attributes.Timestamp / 1e9)
                if message.Attributes
                else datetime.fromtimestamp(0)
            ),
            sequence=message.Attributes.Sequence if message.Attributes else 0,
            receive_count=message.Attributes.ReceiveCount if message.Attributes else 0,
            is_re_routed=message.Attributes.ReRouted if message.Attributes else False,
            re_route_from_queue=(
                message.Attributes.ReRoutedFromQueue if message.Attributes else ""
            ),
            expired_at=(
                datetime.fromtimestamp(message.Attributes.ExpirationAt / 1e6)
                if message.Attributes
                else datetime.fromtimestamp(0)
            ),
            delayed_to=(
                datetime.fromtimestamp(message.Attributes.DelayedTo / 1e6)
                if message.Attributes
                else datetime.fromtimestamp(0)
            ),
            transaction_id=transaction_id,
            is_transaction_completed=transaction_is_completed,
            receiver_client_id=receiver_client_id,
            response_handler=response_handler,
        )

    class Config:
        arbitrary_types_allowed = True
